@@ -1,10 +1,13 @@
 #![cfg_attr(not(feature = "std"), no_std)]
+#![cfg_attr(feature = "experimental", feature(generic_associated_types))] // for http, http::client, http::server, ota
 #![feature(const_btree_new)]
 
 #[cfg(any(feature = "alloc"))]
 #[macro_use]
 extern crate alloc;
 
+#[cfg(all(feature = "experimental", feature = "alloc"))]
+pub mod http;
 #[cfg(any(feature = "std"))] // TODO: Lower requirements to "alloc"
 pub mod httpd;
 #[cfg(any(feature = "alloc"))]
@@ -17,6 +20,7 @@ pub mod netif;
 pub mod nvs;
 #[cfg(any(feature = "alloc"))] // TODO: Expose a subset which does not require "alloc"
 pub mod nvs_storage;
+#[cfg(all(feature = "experimental", feature = "alloc"))]
 pub mod ota;
 pub mod ping;
 pub mod sysloop;
