@@ -4,8 +4,8 @@ extern crate alloc;
 use alloc::sync::Arc;
 use alloc::vec;
 
+use ::log::*;
 use enumset::*;
-use log::*;
 
 use mutex_trait::Mutex;
 
